@@ -18,10 +18,20 @@
 #include "ut_dutil.h"
 #include <QGuiApplication>
 
+#ifdef QT_DEBUG
+#include <sanitizer/asan_interface.h>
+#endif
+
 int main(int argc, char *argv[])
 {
     QCoreApplication app(argc, argv);
 
     testing::InitGoogleTest(&argc, argv);
-    return RUN_ALL_TESTS();
+    int ret = RUN_ALL_TESTS();
+
+#ifdef QT_DEBUG
+    __sanitizer_set_report_path("asan.log");
+#endif
+
+    return ret;
 }
