@@ -23,6 +23,7 @@
 #include <QDBusReply>
 #include <QDir>
 #include <DDesktopEntry>
+#include <QTest>
 
 #include "log/LogManager.h"
 #include "filesystem/dpathbuf.h"
@@ -34,6 +35,7 @@
 #include "settings/dsettingsgroup.h"
 #include "settings/dsettingsoption.h"
 #include "dsysinfo.h"
+#include "base/dsingleton.h"
 
 DCORE_USE_NAMESPACE
 
@@ -71,20 +73,23 @@ TEST_F(ut_DUtil, testDefaultLogPath)
     qputenv("HOME", home);
 }
 
-TEST_F(ut_DUtil, testLogPath)
+TEST_F(ut_DUtil, testDLogManager)
 {
     qApp->setOrganizationName("deepin");
     qApp->setApplicationName("deepin-test-dtk");
 
-    DPathBuf logPath(QStandardPaths::standardLocations(QStandardPaths::HomeLocation).first());
+    DPathBuf logPath(QStandardPaths::standardLocations(QStandardPaths::CacheLocation).first());
 
 #ifdef Q_OS_OSX
-    logPath = logPath / "Library" / "Caches" / "deepin" / "deepin-test-dtk" / "deepin-test-dtk.log";
+    logPath = logPath / "deepin-test-dtk.log";
 #else
-    logPath = logPath / ".cache" / "deepin" / "deepin-test-dtk" / "deepin-test-dtk.log";
+    logPath = logPath / "deepin-test-dtk.log";
 #endif
 
     ASSERT_EQ(DLogManager::getlogFilePath(), logPath.toString());
+    DLogManager::registerFileAppender();
+    DLogManager::registerConsoleAppender();
+    DLogManager::setlogFilePath("%{time}{yyyy-MM-dd, HH:mm:ss.zzz} [%{type:-7}] [%{file:-20} %{function:-35} %{line}] %{message}\n");
 }
 
 TEST_F(ut_DUtil, testSetInvalidLogPath)
@@ -111,28 +116,42 @@ TEST_F(ut_DUtil, testPathChange)
 
 TEST_F(ut_DUtil, testDSingleton)
 {
-    auto threadA = new QThread;
-    auto testerA = new MultiSingletonTester;
-    QObject::connect(threadA, &QThread::started, testerA, &MultiSingletonTester::run);
-    QObject::connect(threadA, &QThread::finished, testerA, [=]() {
-        threadA->deleteLater();
-        testerA->deleteLater();
-    });
-    testerA->moveToThread(threadA);
+    const int exampleCount = 5;
+    QVector<QThread*> threads;
+    QVector<MultiSingletonTester*> testers;
+    threads.reserve(exampleCount);
+    testers.reserve(exampleCount);
+    for (int i = 0; i < exampleCount; i++) {
+        auto thread = new QThread();
+        auto tester = new MultiSingletonTester;
+        tester->moveToThread(thread);
+        QObject::connect(thread, &QThread::started, tester, &MultiSingletonTester::run);
 
-    auto threadB = new QThread;
-    auto testerB = new MultiSingletonTester;
-    testerB->moveToThread(threadB);
-    QObject::connect(threadB, &QThread::started, testerB, &MultiSingletonTester::run);
-    QObject::connect(threadB, &QThread::finished, testerB, [=]() {
-        threadB->deleteLater();
-        testerB->deleteLater();
-    });
+        threads.push_back(thread);
+        testers.push_back(tester);
+        thread->start();
+    }
 
-    threadA->start();
-    threadB->start();
+    for (auto thread : threads) {
+        thread->quit();
+    }
 
-    QThread::sleep(5);
+    ASSERT_TRUE(QTest::qWaitFor([threads] {
+        for (auto thread : threads) {
+            if (!thread->isFinished()) {
+                return false;
+            }
+        }
+        return true;
+    }));
+
+    for (auto tester : testers) {
+        ASSERT_EQ(tester->count(), exampleCount);
+    }
+
+    qDeleteAll(threads);
+    qDeleteAll(testers);
+    delete DSingleton<int>::instance();
 }
 
 TEST_F(ut_DUtil, testTimeFormatter)
@@ -275,6 +294,8 @@ TEST_F(ut_DUtil, testGroups)
     }
     qDebug() << settings->group("shortcuts.ternimal");
     qDebug() << settings->group("shortcuts.ternimal")->options();
+
+    delete settings;
 }
 
 TEST_F(ut_DUtil, testOsVersion)
@@ -459,3 +480,55 @@ TEST_F(ut_DUtil, testOsVersion)
 
     QFile::remove("/tmp/etc/os-version");
 }
+
+TEST_F(ut_DUtil, testDDesktopEntry)
+{
+    DDesktopEntry entry("/tmp/etc/os-version");
+    entry.setStringValue("UnionTech OS Desktop", "SystemName", "Version");
+    entry.setStringValue("统信桌面操作系统", "SystemName[zh_CN]", "Version");
+    entry.setStringValue("Desktop", "ProductType", "Version");
+    entry.setStringValue("桌面", "ProductType[zh_CN]", "Version");
+    entry.setStringValue("Professional", "EditionName", "Version");
+    entry.setStringValue("专业版", "EditionName[zh_CN]", "Version");
+    entry.setStringValue("20", "MajorVersion", "Version");
+    entry.setStringValue("100A", "MinorVersion", "Version");
+    entry.setStringValue("11018.107", "OsBuild", "Version");
+    ASSERT_TRUE(entry.save());
+    ASSERT_TRUE(entry.name().isEmpty());
+    ASSERT_TRUE(entry.genericName().isEmpty());
+    ASSERT_TRUE(entry.ddeDisplayName().isEmpty());
+    ASSERT_TRUE(entry.comment().isEmpty());
+    QString slash("\\\\");
+    ASSERT_TRUE(entry.escapeExec(slash) == slash);
+    ASSERT_TRUE(entry.unescapeExec(slash) == slash);
+}
+
+TEST_F(ut_DUtil, testDSysInfo)
+{
+    DSysInfo::distributionOrgWebsite();
+    DSysInfo::distributionOrgLogo(DSysInfo::Distribution, DSysInfo::Normal);
+    DSysInfo::distributionOrgLogo(DSysInfo::Distribution, DSysInfo::Light);
+    DSysInfo::distributionOrgLogo(DSysInfo::Distribution, DSysInfo::Symbolic);
+    DSysInfo::distributionOrgLogo(DSysInfo::Distribution, DSysInfo::Transparent);
+    ASSERT_TRUE(!DSysInfo::distributionOrgName(DSysInfo::Distribution).isEmpty());
+    ASSERT_TRUE(DSysInfo::distributionOrgName(DSysInfo::Distributor).isEmpty());
+    ASSERT_TRUE(DSysInfo::distributionOrgName(DSysInfo::Manufacturer).isEmpty());
+    ASSERT_TRUE((DSysInfo::isDeepin() == true) || (DSysInfo::isDeepin() == false));
+    ASSERT_TRUE(DSysInfo::isDDE());
+    ASSERT_TRUE(DSysInfo::productType() >= 0);
+    ASSERT_TRUE(!DSysInfo::productTypeString().isEmpty());
+    ASSERT_TRUE(!DSysInfo::productVersion().isEmpty());
+    ASSERT_TRUE(!DSysInfo::cpuModelName().isEmpty());
+    ASSERT_TRUE(!DSysInfo::operatingSystemName().isEmpty());
+    ASSERT_TRUE(DSysInfo::deepinType() >= 0);
+    ASSERT_TRUE(!DSysInfo::deepinTypeDisplayName().isEmpty());
+    ASSERT_TRUE(!DSysInfo::deepinVersion().isEmpty());
+    ASSERT_TRUE(!DSysInfo::deepinEdition().isEmpty());
+    ASSERT_TRUE(!DSysInfo::deepinCopyright().isEmpty());
+    ASSERT_TRUE(DSysInfo::distributionInfoPath().size() >= 0);
+    ASSERT_TRUE(DSysInfo::isCommunityEdition() == true || DSysInfo::isCommunityEdition() == false);
+    ASSERT_TRUE(!DSysInfo::computerName().isEmpty());
+    ASSERT_TRUE(DSysInfo::memoryInstalledSize() >= -1);
+    qDebug() << DSysInfo::memoryTotalSize();
+    ASSERT_TRUE(DSysInfo::systemDiskSize() >= -1);
+}
